"""General-use classes to interact with the IoTThingsGraph service through CloudFormation.

See Also:
    `AWS developer guide for IoTThingsGraph
    <https://docs.aws.amazon.com/thingsgraph/latest/ug/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iotthingsgraph as _raw

# noinspection PyUnresolvedReferences
from .._raw.iotthingsgraph import *
