"""General-use classes to interact with the PinpointEmail service through CloudFormation.

See Also:
    `AWS developer guide for PinpointEmail
    <http://docs.aws.amazon.com/pinpoint/latest/userguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import pinpointemail as _raw

# noinspection PyUnresolvedReferences
from .._raw.pinpointemail import *
