"""Raw representations of every data type in the AWS SecurityHub service.

See Also:
    `AWS developer guide for SecurityHub
    <https://docs.aws.amazon.com/securityhub/latest/userguide/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = ["Hub", "HubProperties"]


@attrs(**ATTRSCONFIG)
class HubProperties(ResourceProperties):
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Hub(Resource):
    """A Hub for SecurityHub.

    See Also:
        `AWS Cloud Formation documentation for Hub
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-hub.html>`_
    """

    RESOURCE_TYPE = "AWS::SecurityHub::Hub"

    Properties: HubProperties = attrib(
        factory=HubProperties, converter=create_object_converter(HubProperties)
    )
