"""General-use classes to interact with the Transfer service through CloudFormation.

See Also:
    `AWS developer guide for Transfer
    <https://docs.aws.amazon.com/transfer/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import transfer as _raw

# noinspection PyUnresolvedReferences
from .._raw.transfer import *
